# Phase 3. Explore: Define the To-Be Architecture
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/erp-transformation-explore#overview)
  * [Step 1. Add Transformations and Impacts With Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/erp-transformation-explore#step-1.-add-transformations-and-impacts-with-architecture-and-road-map-planning)
  * [Step 2. Evaluate Data](https://help.sap.com/docs/leanix/ea/erp-transformation-explore#step-2.-evaluate-data)
  * [Step 3. Report and Communicate](https://help.sap.com/docs/leanix/ea/erp-transformation-explore#step-3.-report-and-communicate)


Detail the impact of the transformation on your landscape and refine the target architecture.
